{{
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// VGA64 6 Bits Per Pixel Engine
//
// Author: Kwabena W. Agyeman
// Updated: 11/17/2010
// Designed For: P8X32A
// Version: 1.0
//
// Copyright (c) 2010 Kwabena W. Agyeman
// See end of file for terms of use.
//
// Update History:
//
// v1.0 - Original release - 11/17/2009.
//
// For each included copy of this object only one spin interpreter should access it at a time.
//
// Nyamekye,
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// "Pluto1b" hard coded data added by Tubular 10Jul15.  Needs greyscale resistors as per details below.  

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Video Circuit:    FOR 64 LEVEL GREYSCALE:-
//
// *** OR ALTERNATIVELY USE A R/2R LADDER WITH ~90 and ~160 ohm elements ***
//
//     0   1   2   3 Pin Group
//
//                     240OHM
// Pin 0,  8, 16, 24 ----R-------- Vertical Sync
//
//                     240OHM
// Pin 1,  9, 17, 25 ----R-------- Horizontal Sync
//
//                     5760OHM
// Pin 2, 10, 18, 26 ----R-----    - Blue Video   (3 signals driven in parallel, 25 ohm effective loading)
//                            |    |
//                     2870OHM|    |
// Pin 3, 11, 19, 27 ----R-----    |
//                            |    |
//                     1430OHM|    |
// Pin 4, 12, 20, 28 ----R-----    - Green Video
//                            |    |
//                     698OHM |    |
// Pin 5, 13, 21, 29 ----R-----    |
//                            |    |
//                     340OHM |    |
// Pin 6, 14, 22, 30 ----R---------- Red Video
//                            |
//                     154OHM |
// Pin 7, 15, 23, 31 ----R-----
//
//                            5V
//                            |
//                            --- 5V
//
//                            --- Vertical Sync Ground
//                            |
//                           GND
//
//                            --- Hoirzontal Sync Ground
//                            |
//                           GND
//
//                            --- Blue Return
//                            |
//                           GND
//
//                            --- Green Return
//                            |
//                           GND
//
//                            --- Red Return
//                            |
//                           GND
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
}}

CON

  #$FC, Light_Grey, #$A8, Grey, #$54, Dark_Grey
  #$C0, Light_Red, #$80, Red, #$40, Dark_Red
  #$30, Light_Green, #$20, Green, #$10, Dark_Green
  #$0C, Light_Blue, #$08, Blue, #$04, Dark_Blue
  #$F0, Light_Orange, #$A0, Orange, #$50, Dark_Orange
  #$CC, Light_Purple, #$88, Purple, #$44, Dark_Purple
  #$3C, Light_Teal, #$28, Teal, #$14, Dark_Teal
  #$FF, White, #$00, Black

PUB plotBox(color, xPixelStart, yPixelStart, xPixelEnd, yPixelEnd) '' 8 Stack Longs

'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'' // Plots a one color box of pixels on screen.
'' //
'' // Color - The color of the box of pixels to display on screen. A color byte (%RR_GG_BB_xx).
'' // XPixelStart - The X cartesian pixel start coordinate. X between 0 and 159. Y between 0 and 119.
'' // YPixelStart - The Y cartesian pixel start coordinate. Note that this axis is inverted like on all other graphics drivers.
'' // XPixelEnd - The X cartesian pixel end coordinate. X between 0 and 159. Y between 0 and 119.
'' // YPixelEnd - The Y cartesian pixel end coordinate. Note that this axis is inverted like on all other graphics drivers.
'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

  xPixelEnd := ((xPixelEnd <# 159) #> 0)
  yPixelEnd := (((yPixelEnd <# 119) #> 0) * 160)
  xPixelStart := ((xPixelStart <# xPixelEnd) #> 0)
  yPixelStart := (((yPixelStart * 160) <# yPixelEnd) #> 0)

  yPixelEnd += xPixelStart
  yPixelStart += xPixelStart
  xPixelEnd -= --xPixelStart

  repeat result from yPixelStart to yPixelEnd step 160
    bytefill(@displayBuffer + result, (color | $3), xPixelEnd)

PUB getPixel(color, xPixel, yPixel)
'' Determine the colour of a pixel

  color :=  displayBuffer.byte[((xPixel <# 159) #> 0) + (160 * ((yPixel <# 119) #> 0))]

PUB plotPixel(color, xPixel, yPixel) '' 6 Stack Longs

'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'' // Plots a one color pixel on screen.
'' //
'' // Color - The color of the pixel to display on screen. A color byte (%RR_GG_BB_xx).
'' // XPixel - The X cartesian pixel coordinate. X between 0 and 159. Y between 0 and 119.
'' // YPixel - The Y cartesian pixel coordinate. Note that this axis is inverted like on all other graphics drivers.
'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

  displayBuffer.byte[((xPixel <# 159) #> 0) + (160 * ((yPixel <# 119) #> 0))] := (color | $3)

PUB displayClear '' 3 Stack Longs

'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'' // Clears the screen to black.
'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

  longfill(@displayBuffer, 0, constant((160 * 120) / 4))

PUB displayPointer '' 3 Stack Longs

'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'' // Returns a pointer to the display buffer.
'' //
'' // The display buffer is an array of 160 by 120 bytes. Each byte represents a pixel on the screen.
'' //
'' // Each pixel is a color byte (%RR_GG_BB_xx). Where RR, GG, and BB are the two bit values of red, green, blue respectively.
'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

  return @displayBuffer

PUB displayState(state) '' 4 Stack Longs

'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'' // Enables or disables the PIX Driver's video output - turning the monitor off or putting it into standby mode.
'' //
'' // State - True for active and false for inactive.
'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

  displayIndicator := state

PUB displayRate(rate) '' 4 Stack Longs

'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'' // Returns true or false depending on the time elasped according to a specified rate.
'' //
'' // Rate - A display rate to return at. 0=0.234375Hz, 1=0.46875Hz, 2=0.9375Hz, 3=1.875Hz, 4=3.75Hz, 5=7.5Hz, 6=15Hz, 7=30Hz.
'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

  result or= (($80 >> ((rate <# 7) #> 0)) & syncIndicator)

PUB displayWait(frames) '' 4 Stack Longs

'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'' // Waits for the display vertical refresh.
'' //
'' // The best time to draw on screen for flicker free operation is right after this function returns.
'' //
'' // Frames - Number of vertical refresh frames to wait for.
'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

  repeat (frames #> 0)
    result := syncIndicator
    repeat until(result <> syncIndicator)

PUB displayColor(redAmount, greenAmount, blueAmount) '' 6 Stack Longs

'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'' // Builds a color byte (%RR_GG_BB_xx) from red, green, and blue componets.
'' //
'' // RedAmount - The amount of red to add to the color byte. Between 0 and 3.
'' // GreenAmount - The amount of green to add to the color byte. Between 0 and 3.
'' // BlueAmount - The amount of blue to add to the color byte. Between 0 and 3.
'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

  return ((((redAmount <# 3) #> 0) << 6) | (((greenAmount <# 3) #> 0) << 4) | (((blueAmount <# 3) #> 0) << 2) | $3)

PUB PIXEngineStart(pinGroup) '' 7 Stack Longs

'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'' // Starts up the PIX driver running on a cog.
'' //
'' // Returns true on success and false on failure.
'' //
'' // PinGroup - Pin group to use to drive the video circuit. Between 0 and 3.
'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

  PIXEngineStop
  if(chipver == 1)

    pinGroup := ((pinGroup <# 3) #> 0)
    directionState := ($FF << (8 * pinGroup))
    videoState := ($30_00_00_FF | (pinGroup << 9))

    pinGroup := constant((25_175_000 + 1_600) / 4)
    frequencyState := 1

    repeat 32
      pinGroup <<= 1
      frequencyState <-= 1
      if(pinGroup => clkfreq)
        pinGroup -= clkfreq
        frequencyState += 1

    displayIndicatorAddress := @displayIndicator
    syncIndicatorAddress := @syncIndicator
    cogNumber := cognew(@initialization, @displayBuffer)
    result or= ++cogNumber

PUB PIXEngineStop '' 3 Stack Longs

'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'' // Shuts down the PIX driver running on a cog.
'' ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

  if(cogNumber)
    cogstop(-1 + cogNumber~)

DAT

' /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'                       PIX Driver
' /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

                        org     0

' //////////////////////Initialization/////////////////////////////////////////////////////////////////////////////////////////

initialization          mov     vcfg,           videoState                 ' Setup video hardware.
                        mov     frqa,           frequencyState             '
                        movi    ctra,           #%0_00001_101              '

' /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'                       Active Video
' /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

loop                    mov     displayCounter, par                        ' Set/Reset tiles fill counter.
                        mov     tilesCounter,   #120                       '

tilesDisplay            mov     tileCounter,    #4                         ' Set/Reset tile fill counter.

tileDisplay             mov     vscl,           visibleScale               ' Set/Reset the video scale.
                        mov     counter,        #40                        '

' //////////////////////Visible Video//////////////////////////////////////////////////////////////////////////////////////////

videoLoop               rdlong  buffer,         displayCounter             ' Download new pixels.
                        add     displayCounter, #4                         '

                        or      buffer,         HVSyncColors               ' Update display scanline.
                        waitvid buffer,         #%%3210                    '

                        djnz    counter,        #videoLoop                 ' Repeat.

' //////////////////////Invisible Video////////////////////////////////////////////////////////////////////////////////////////

                        mov     vscl,           invisibleScale             ' Set/Reset the video scale.

                        waitvid HSyncColors,    syncPixels                 ' Horizontal Sync.

' //////////////////////Repeat/////////////////////////////////////////////////////////////////////////////////////////////////

                        sub     displayCounter, #160                       ' Repeat.
                        djnz    tileCounter,    #tileDisplay               '

                        add     displayCounter, #160                       ' Repeat.
                        djnz    tilesCounter,   #tilesDisplay              '

' /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'                       Inactive Video
' /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

                        add     refreshCounter, #1                         ' Update sync indicator.
                        wrbyte  refreshCounter, syncIndicatorAddress       '

' //////////////////////Front Porch////////////////////////////////////////////////////////////////////////////////////////////

                        mov     counter,        #11                        ' Set loop counter.

frontPorch              mov     vscl,           blankPixels                ' Invisible lines.
                        waitvid HSyncColors,    #0                         '

                        mov     vscl,           invisibleScale             ' Horizontal Sync.
                        waitvid HSyncColors,    syncPixels                 '

                        djnz    counter,        #frontPorch                ' Repeat # times.

' //////////////////////Vertical Sync//////////////////////////////////////////////////////////////////////////////////////////

                        mov     counter,        #(2 + 2)                   ' Set loop counter.

verticalSync            mov     vscl,           blankPixels                ' Invisible lines.
                        waitvid VSyncColors,    #0                         '

                        mov     vscl,           invisibleScale             ' Vertical Sync.
                        waitvid VSyncColors,    syncPixels                 '

                        djnz    counter,        #verticalSync              ' Repeat # times.

' //////////////////////Back Porch/////////////////////////////////////////////////////////////////////////////////////////////

                        mov     counter,        #31                        ' Set loop counter.

backPorch               mov     vscl,           blankPixels                ' Invisible lines.
                        waitvid HSyncColors,    #0                         '

                        mov     vscl,           invisibleScale             ' Horizontal Sync.
                        waitvid HSyncColors,    syncPixels                 '

                        djnz    counter,        #backPorch                 ' Repeat # times.

' //////////////////////Update Display Settings////////////////////////////////////////////////////////////////////////////////

                        rdbyte  buffer,         displayIndicatorAddress wz ' Update display settings.
                        muxnz   dira,           directionState             '

' //////////////////////Loop///////////////////////////////////////////////////////////////////////////////////////////////////

                        jmp     #loop                                      ' Loop.

' /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
'                       Data
' /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

invisibleScale          long    (16 << 12) + 160                           ' Scaling for inactive video.
visibleScale            long    (4 << 12) + 16                             ' Scaling for active video.
blankPixels             long    640                                        ' Blank scanline pixel length.
syncPixels              long    $00_00_3F_FC                               ' F-porch, h-sync, and b-porch.
HSyncColors             long    $01_03_01_03                               ' Horizontal sync color mask.
VSyncColors             long    $00_02_00_02                               ' Vertical sync color mask.
HVSyncColors            long    $03_03_03_03                               ' Horizontal and vertical sync colors.

' //////////////////////Configuration Settings/////////////////////////////////////////////////////////////////////////////////

directionState          long    0
videoState              long    0
frequencyState          long    0

' //////////////////////Addresses//////////////////////////////////////////////////////////////////////////////////////////////

displayIndicatorAddress long    0
syncIndicatorAddress    long    0

' //////////////////////Run Time Variables/////////////////////////////////////////////////////////////////////////////////////

counter                 res     1
buffer                  res     1

tileCounter             res     1
tilesCounter            res     1

refreshCounter          res     1
displayCounter          res     1

' /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

                        fit     496

DAT

' //////////////////////Variable Arrary////////////////////////////////////////////////////////////////////////////////////////

displayBuffer           byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte  1 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 1 , 1 , 1 , 1 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 1 , 1 , 1 , 1 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 1 , 1 , 1 , 1 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 1 , 1 , 1 , 1 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 1 , 1 , 1 , 1 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 1 , 1 , 1 , 1 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  3 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 3 
                        byte  3 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 4 , 4 , 4 , 4 , 4 , 4 , 4 
                        byte  4 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  3 , 3 , 4 , 4 , 4 , 3 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 4 , 4 , 4 , 4 
                        byte  4 , 2 , 2 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte  1 , 1 , 1 , 1 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  3 , 2 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 1 , 2 , 3 , 3 , 3 , 3 , 4 
                        byte  4 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 5 , 4 , 4 , 4 , 3 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 3 , 2 
                        byte  2 , 3 , 3 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte  1 , 1 , 1 , 1 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 4 , 4 , 4 
                        byte  4 , 5 , 5 , 6 , 6 , 5 , 5 , 5 
                        byte  5 , 6 , 6 , 6 , 5 , 5 , 5 , 5 
                        byte  5 , 4 , 4 , 4 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 4 , 4 , 4 , 4 , 4 , 4 , 4 
                        byte  4 , 4 , 5 , 5 , 5 , 4 , 3 , 4 
                        byte  4 , 6 , 6 , 5 , 5 , 5 , 5 , 5 
                        byte  5 , 5 , 5 , 5 , 5 , 5 , 5 , 5 
                        byte  5 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 4 , 4 , 4 , 4 , 4 , 4 , 4 
                        byte  4 , 5 , 6 , 6 , 6 , 6 , 7 , 7 
                        byte  8 , 7 , 7 , 8 , 8 , 8 , 8 , 7 
                        byte  7 , 7 , 7 , 6 , 6 , 5 , 5 , 5 
                        byte  5 , 4 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  4 , 4 , 4 , 4 , 5 , 5 , 5 , 5 
                        byte  6 , 8 , 8 , 9 , 9 , 9 , 9 , 10 
                        byte  11 , 9 , 10 , 10 , 11 , 11 , 10 , 9 
                        byte  9 , 7 , 7 , 6 , 5 , 5 , 5 , 5 
                        byte  6 , 4 , 4 , 4 , 4 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 4 , 4 
                        byte  4 , 4 , 5 , 5 , 6 , 6 , 7 , 7 
                        byte  7 , 7 , 8 , 10 , 11 , 12 , 14 , 16 
                        byte  17 , 20 , 20 , 21 , 22 , 21 , 19 , 18 
                        byte  16 , 15 , 14 , 13 , 11 , 9 , 8 , 7 
                        byte  7 , 6 , 6 , 5 , 5 , 4 , 4 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 4 , 4 , 4 
                        byte  4 , 5 , 5 , 6 , 6 , 7 , 8 , 8 
                        byte  8 , 12 , 14 , 17 , 22 , 26 , 31 , 35 
                        byte  38 , 43 , 44 , 45 , 46 , 45 , 42 , 40 
                        byte  38 , 31 , 29 , 25 , 20 , 15 , 11 , 8 
                        byte  7 , 7 , 7 , 6 , 5 , 5 , 4 , 4 
                        byte  4 , 4 , 4 , 4 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 3 , 3 
                        byte  3 , 5 , 4 , 2 , 3 , 6 , 4 , 3 
                        byte  6 , 4 , 6 , 6 , 7 , 9 , 9 , 11 
                        byte  16 , 17 , 25 , 36 , 46 , 55 , 64 , 72 
                        byte  76 , 81 , 84 , 85 , 83 , 81 , 79 , 76 
                        byte  72 , 65 , 59 , 50 , 42 , 34 , 25 , 17 
                        byte  12 , 10 , 8 , 7 , 6 , 4 , 5 , 7 
                        byte  4 , 5 , 5 , 5 , 4 , 3 , 3 , 3 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  3 , 2 , 4 , 4 , 4 , 7 , 6 , 5 
                        byte  7 , 7 , 9 , 10 , 11 , 13 , 14 , 21 
                        byte  31 , 49 , 62 , 80 , 93 , 102 , 110 , 115 
                        byte  118 , 119 , 121 , 121 , 118 , 115 , 112 , 108 
                        byte  104 , 97 , 92 , 83 , 74 , 63 , 51 , 38 
                        byte  28 , 20 , 14 , 11 , 9 , 6 , 6 , 6 
                        byte  4 , 5 , 4 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  3 , 2 , 5 , 5 , 3 , 5 , 5 , 5 
                        byte  6 , 7 , 9 , 11 , 15 , 23 , 33 , 51 
                        byte  69 , 87 , 101 , 119 , 132 , 137 , 139 , 141 
                        byte  141 , 144 , 145 , 144 , 139 , 134 , 132 , 127 
                        byte  122 , 119 , 117 , 111 , 103 , 95 , 84 , 69 
                        byte  56 , 40 , 29 , 20 , 14 , 9 , 7 , 6 
                        byte  5 , 6 , 4 , 3 , 3 , 3 , 4 , 3 
                        byte  2 , 3 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 6 , 4 , 2 , 5 , 7 , 7 
                        byte  9 , 9 , 12 , 18 , 30 , 48 , 70 , 95 
                        byte  116 , 135 , 144 , 155 , 161 , 163 , 162 , 161 
                        byte  160 , 158 , 158 , 154 , 148 , 144 , 140 , 136 
                        byte  131 , 126 , 125 , 121 , 116 , 113 , 108 , 96 
                        byte  85 , 69 , 55 , 40 , 29 , 18 , 11 , 9 
                        byte  7 , 7 , 5 , 4 , 5 , 4 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  4 , 3 , 5 , 4 , 4 , 8 , 10 , 10 
                        byte  12 , 15 , 26 , 42 , 64 , 91 , 115 , 135 
                        byte  148 , 160 , 164 , 168 , 171 , 172 , 173 , 172 
                        byte  170 , 169 , 169 , 165 , 159 , 154 , 151 , 146 
                        byte  141 , 136 , 132 , 126 , 122 , 121 , 119 , 112 
                        byte  105 , 97 , 84 , 70 , 55 , 38 , 24 , 14 
                        byte  8 , 6 , 5 , 5 , 6 , 5 , 3 , 3 
                        byte  4 , 3 , 3 , 3 , 3 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 4 
                        byte  4 , 3 , 5 , 6 , 7 , 9 , 9 , 11 
                        byte  16 , 29 , 52 , 80 , 107 , 133 , 152 , 161 
                        byte  165 , 174 , 176 , 179 , 180 , 183 , 185 , 184 
                        byte  182 , 177 , 177 , 173 , 167 , 162 , 160 , 155 
                        byte  149 , 146 , 140 , 132 , 128 , 126 , 124 , 120 
                        byte  116 , 112 , 105 , 96 , 83 , 66 , 47 , 28 
                        byte  14 , 9 , 6 , 5 , 6 , 5 , 3 , 3 
                        byte  5 , 3 , 3 , 3 , 3 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 1 , 1 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 4 , 4 
                        byte  4 , 5 , 7 , 7 , 8 , 9 , 11 , 21 
                        byte  35 , 63 , 93 , 124 , 144 , 160 , 171 , 175 
                        byte  176 , 178 , 181 , 184 , 185 , 187 , 189 , 189 
                        byte  187 , 186 , 186 , 182 , 176 , 172 , 170 , 164 
                        byte  159 , 154 , 147 , 140 , 138 , 135 , 130 , 125 
                        byte  123 , 121 , 118 , 114 , 108 , 96 , 79 , 56 
                        byte  35 , 20 , 13 , 6 , 5 , 6 , 4 , 3 
                        byte  4 , 3 , 3 , 3 , 3 , 3 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 1 , 1 , 1 , 1 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 4 , 4 
                        byte  4 , 5 , 6 , 7 , 9 , 11 , 18 , 39 
                        byte  63 , 101 , 132 , 159 , 166 , 170 , 176 , 180 
                        byte  182 , 182 , 186 , 189 , 190 , 191 , 193 , 195 
                        byte  195 , 192 , 191 , 187 , 182 , 178 , 175 , 170 
                        byte  164 , 163 , 156 , 151 , 150 , 145 , 137 , 130 
                        byte  129 , 127 , 126 , 125 , 123 , 118 , 107 , 84 
                        byte  59 , 31 , 20 , 9 , 6 , 7 , 5 , 3 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 3 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 1 , 1 , 1 , 1 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 4 , 4 , 4 
                        byte  5 , 5 , 6 , 9 , 14 , 17 , 31 , 68 
                        byte  110 , 147 , 163 , 175 , 178 , 180 , 183 , 184 
                        byte  186 , 187 , 187 , 196 , 195 , 199 , 196 , 202 
                        byte  201 , 196 , 196 , 194 , 190 , 185 , 182 , 179 
                        byte  177 , 172 , 168 , 160 , 153 , 147 , 144 , 141 
                        byte  140 , 137 , 136 , 137 , 137 , 132 , 123 , 105 
                        byte  87 , 61 , 31 , 13 , 12 , 7 , 5 , 5 
                        byte  2 , 4 , 4 , 3 , 3 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 4 , 4 , 5 
                        byte  5 , 7 , 10 , 12 , 17 , 33 , 63 , 106 
                        byte  142 , 167 , 178 , 185 , 187 , 188 , 188 , 188 
                        byte  190 , 190 , 191 , 201 , 201 , 204 , 202 , 207 
                        byte  206 , 201 , 201 , 198 , 193 , 188 , 184 , 180 
                        byte  177 , 177 , 173 , 166 , 159 , 154 , 151 , 150 
                        byte  148 , 148 , 146 , 144 , 142 , 137 , 131 , 121 
                        byte  110 , 83 , 54 , 30 , 17 , 7 , 6 , 8 
                        byte  4 , 4 , 4 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 4 , 4 , 5 , 6 
                        byte  6 , 8 , 12 , 15 , 27 , 59 , 104 , 146 
                        byte  172 , 186 , 191 , 194 , 195 , 196 , 194 , 193 
                        byte  195 , 194 , 196 , 204 , 206 , 208 , 207 , 210 
                        byte  208 , 202 , 202 , 200 , 196 , 193 , 190 , 187 
                        byte  184 , 180 , 176 , 171 , 165 , 161 , 158 , 156 
                        byte  155 , 154 , 153 , 156 , 155 , 148 , 141 , 132 
                        byte  123 , 104 , 80 , 51 , 27 , 9 , 7 , 8 
                        byte  4 , 4 , 4 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 3 
                        byte  3 , 3 , 3 , 3 , 4 , 4 , 5 , 6 
                        byte  8 , 9 , 14 , 24 , 52 , 96 , 140 , 170 
                        byte  186 , 193 , 196 , 199 , 202 , 203 , 199 , 197 
                        byte  200 , 199 , 200 , 206 , 209 , 211 , 212 , 212 
                        byte  208 , 203 , 203 , 202 , 199 , 197 , 195 , 192 
                        byte  189 , 183 , 179 , 173 , 169 , 165 , 160 , 157 
                        byte  157 , 154 , 155 , 160 , 163 , 158 , 149 , 140 
                        byte  131 , 116 , 97 , 72 , 44 , 21 , 10 , 8 
                        byte  5 , 4 , 4 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 4 , 4 , 5 , 7 
                        byte  9 , 13 , 19 , 43 , 89 , 138 , 168 , 184 
                        byte  195 , 196 , 200 , 205 , 209 , 209 , 203 , 200 
                        byte  203 , 204 , 204 , 207 , 212 , 215 , 219 , 217 
                        byte  211 , 210 , 210 , 207 , 203 , 200 , 197 , 193 
                        byte  189 , 186 , 182 , 177 , 172 , 167 , 161 , 157 
                        byte  156 , 156 , 154 , 157 , 162 , 161 , 157 , 152 
                        byte  147 , 127 , 112 , 91 , 66 , 38 , 16 , 8 
                        byte  7 , 4 , 4 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 4 , 4 , 4 , 6 , 9 
                        byte  11 , 16 , 32 , 70 , 124 , 168 , 186 , 194 
                        byte  202 , 201 , 205 , 210 , 213 , 213 , 208 , 203 
                        byte  205 , 209 , 209 , 209 , 215 , 217 , 224 , 221 
                        byte  215 , 216 , 215 , 212 , 207 , 204 , 200 , 195 
                        byte  190 , 187 , 182 , 177 , 174 , 168 , 160 , 155 
                        byte  154 , 157 , 152 , 155 , 162 , 164 , 162 , 158 
                        byte  155 , 141 , 127 , 107 , 85 , 56 , 26 , 10 
                        byte  8 , 5 , 4 , 4 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 4 , 4 , 5 , 5 , 7 , 11 
                        byte  14 , 23 , 57 , 107 , 155 , 186 , 197 , 199 
                        byte  204 , 206 , 210 , 212 , 215 , 218 , 216 , 212 
                        byte  212 , 216 , 216 , 215 , 220 , 219 , 227 , 225 
                        byte  220 , 218 , 217 , 214 , 210 , 207 , 203 , 198 
                        byte  193 , 186 , 181 , 177 , 174 , 168 , 160 , 154 
                        byte  153 , 153 , 150 , 156 , 166 , 168 , 164 , 159 
                        byte  156 , 153 , 139 , 120 , 101 , 76 , 44 , 19 
                        byte  11 , 6 , 6 , 5 , 4 , 4 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  4 , 3 , 4 , 5 , 5 , 6 , 8 , 12 
                        byte  15 , 35 , 83 , 140 , 179 , 199 , 205 , 205 
                        byte  204 , 210 , 213 , 213 , 216 , 222 , 224 , 223 
                        byte  222 , 224 , 225 , 223 , 226 , 222 , 230 , 228 
                        byte  225 , 220 , 218 , 215 , 211 , 207 , 204 , 198 
                        byte  193 , 186 , 181 , 177 , 175 , 170 , 161 , 155 
                        byte  154 , 151 , 148 , 155 , 166 , 169 , 166 , 164 
                        byte  163 , 158 , 147 , 129 , 112 , 92 , 61 , 30 
                        byte  15 , 7 , 7 , 6 , 5 , 4 , 4 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  4 , 4 , 0 , 5 , 6 , 5 , 11 , 16 
                        byte  23 , 56 , 113 , 167 , 192 , 199 , 206 , 211 
                        byte  205 , 211 , 211 , 213 , 216 , 221 , 226 , 229 
                        byte  231 , 228 , 229 , 229 , 228 , 227 , 228 , 228 
                        byte  228 , 226 , 221 , 215 , 211 , 209 , 207 , 203 
                        byte  199 , 192 , 184 , 176 , 172 , 168 , 160 , 153 
                        byte  149 , 146 , 149 , 154 , 165 , 175 , 174 , 168 
                        byte  167 , 162 , 154 , 140 , 127 , 105 , 79 , 49 
                        byte  15 , 9 , 6 , 6 , 3 , 2 , 4 , 1 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  4 , 6 , 4 , 7 , 8 , 8 , 11 , 19 
                        byte  33 , 81 , 135 , 180 , 198 , 201 , 204 , 209 
                        byte  207 , 212 , 213 , 215 , 218 , 222 , 226 , 230 
                        byte  233 , 232 , 232 , 230 , 229 , 229 , 231 , 230 
                        byte  228 , 226 , 223 , 219 , 215 , 211 , 207 , 202 
                        byte  199 , 193 , 186 , 179 , 175 , 169 , 162 , 157 
                        byte  156 , 148 , 149 , 153 , 163 , 176 , 179 , 176 
                        byte  176 , 168 , 160 , 147 , 135 , 116 , 92 , 63 
                        byte  30 , 12 , 6 , 6 , 3 , 3 , 5 , 2 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  4 , 5 , 5 , 7 , 7 , 10 , 11 , 22 
                        byte  50 , 113 , 161 , 193 , 202 , 204 , 205 , 209 
                        byte  212 , 215 , 217 , 219 , 221 , 223 , 227 , 232 
                        byte  235 , 236 , 234 , 231 , 229 , 230 , 231 , 230 
                        byte  227 , 225 , 224 , 221 , 218 , 213 , 207 , 201 
                        byte  197 , 191 , 186 , 181 , 176 , 169 , 163 , 160 
                        byte  161 , 156 , 157 , 158 , 165 , 178 , 185 , 183 
                        byte  180 , 173 , 165 , 152 , 142 , 126 , 104 , 78 
                        byte  46 , 16 , 7 , 6 , 4 , 3 , 5 , 2 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  4 , 2 , 5 , 5 , 6 , 11 , 12 , 30 
                        byte  72 , 136 , 177 , 198 , 202 , 207 , 208 , 212 
                        byte  218 , 218 , 221 , 224 , 225 , 226 , 228 , 231 
                        byte  235 , 237 , 235 , 233 , 230 , 229 , 229 , 228 
                        byte  226 , 223 , 222 , 220 , 218 , 214 , 207 , 200 
                        byte  195 , 189 , 186 , 183 , 179 , 174 , 169 , 167 
                        byte  168 , 169 , 170 , 168 , 171 , 183 , 191 , 188 
                        byte  182 , 176 , 167 , 155 , 146 , 132 , 113 , 88 
                        byte  58 , 24 , 9 , 6 , 5 , 4 , 5 , 3 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  4 , 3 , 6 , 6 , 7 , 13 , 16 , 43 
                        byte  97 , 153 , 185 , 199 , 203 , 211 , 213 , 216 
                        byte  221 , 221 , 225 , 228 , 229 , 228 , 228 , 230 
                        byte  232 , 237 , 238 , 236 , 232 , 229 , 227 , 227 
                        byte  227 , 224 , 222 , 219 , 216 , 213 , 207 , 199 
                        byte  193 , 190 , 188 , 187 , 188 , 187 , 184 , 181 
                        byte  180 , 182 , 182 , 177 , 176 , 186 , 193 , 191 
                        byte  186 , 180 , 172 , 160 , 151 , 138 , 120 , 98 
                        byte  68 , 32 , 12 , 6 , 6 , 4 , 5 , 3 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  4 , 5 , 7 , 7 , 7 , 13 , 21 , 58 
                        byte  119 , 168 , 192 , 202 , 208 , 216 , 218 , 220 
                        byte  222 , 226 , 229 , 232 , 232 , 231 , 230 , 230 
                        byte  232 , 239 , 240 , 240 , 235 , 231 , 229 , 228 
                        byte  228 , 226 , 223 , 219 , 215 , 210 , 205 , 199 
                        byte  194 , 195 , 194 , 195 , 198 , 201 , 200 , 197 
                        byte  194 , 197 , 195 , 188 , 183 , 187 , 191 , 189 
                        byte  186 , 183 , 175 , 163 , 155 , 141 , 125 , 105 
                        byte  77 , 42 , 15 , 7 , 7 , 3 , 4 , 4 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  4 , 5 , 6 , 7 , 9 , 15 , 29 , 75 
                        byte  140 , 179 , 197 , 208 , 215 , 220 , 222 , 227 
                        byte  227 , 233 , 235 , 236 , 236 , 234 , 234 , 234 
                        byte  236 , 240 , 241 , 240 , 236 , 232 , 230 , 228 
                        byte  227 , 224 , 223 , 219 , 213 , 207 , 202 , 200 
                        byte  200 , 204 , 204 , 206 , 209 , 211 , 210 , 207 
                        byte  204 , 205 , 205 , 199 , 194 , 193 , 192 , 188 
                        byte  186 , 183 , 176 , 165 , 157 , 143 , 128 , 110 
                        byte  85 , 49 , 18 , 7 , 7 , 3 , 4 , 4 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  4 , 5 , 6 , 9 , 11 , 18 , 37 , 88 
                        byte  156 , 183 , 199 , 211 , 219 , 223 , 226 , 233 
                        byte  232 , 239 , 239 , 239 , 239 , 238 , 238 , 239 
                        byte  241 , 239 , 239 , 237 , 234 , 232 , 230 , 227 
                        byte  224 , 220 , 220 , 217 , 211 , 203 , 200 , 202 
                        byte  205 , 214 , 214 , 216 , 217 , 217 , 216 , 212 
                        byte  209 , 204 , 207 , 206 , 203 , 201 , 196 , 190 
                        byte  188 , 183 , 177 , 166 , 158 , 145 , 131 , 115 
                        byte  90 , 54 , 20 , 8 , 8 , 3 , 3 , 4 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 4 , 5 
                        byte  5 , 7 , 6 , 7 , 15 , 19 , 40 , 107 
                        byte  170 , 188 , 202 , 210 , 217 , 228 , 230 , 233 
                        byte  244 , 246 , 244 , 242 , 241 , 241 , 241 , 241 
                        byte  241 , 240 , 237 , 232 , 234 , 232 , 228 , 229 
                        byte  224 , 217 , 215 , 215 , 211 , 206 , 202 , 201 
                        byte  212 , 214 , 216 , 219 , 220 , 219 , 216 , 215 
                        byte  216 , 210 , 208 , 207 , 207 , 205 , 200 , 194 
                        byte  191 , 186 , 180 , 172 , 165 , 150 , 133 , 116 
                        byte  95 , 61 , 24 , 9 , 8 , 3 , 3 , 4 
                        byte  4 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 4 , 5 
                        byte  5 , 6 , 7 , 7 , 13 , 21 , 51 , 119 
                        byte  176 , 192 , 203 , 210 , 217 , 229 , 232 , 233 
                        byte  241 , 245 , 245 , 244 , 245 , 245 , 245 , 244 
                        byte  243 , 240 , 235 , 230 , 232 , 232 , 229 , 228 
                        byte  221 , 218 , 213 , 212 , 209 , 208 , 206 , 204 
                        byte  213 , 213 , 216 , 219 , 221 , 219 , 216 , 214 
                        byte  213 , 210 , 210 , 209 , 207 , 204 , 199 , 195 
                        byte  192 , 186 , 181 , 174 , 167 , 152 , 136 , 121 
                        byte  100 , 66 , 28 , 9 , 7 , 4 , 5 , 4 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 4 , 5 
                        byte  5 , 5 , 8 , 8 , 11 , 22 , 62 , 132 
                        byte  183 , 200 , 208 , 213 , 220 , 231 , 235 , 235 
                        byte  240 , 244 , 245 , 247 , 249 , 250 , 248 , 246 
                        byte  244 , 241 , 234 , 226 , 228 , 229 , 226 , 225 
                        byte  217 , 216 , 209 , 206 , 205 , 207 , 208 , 205 
                        byte  211 , 213 , 218 , 222 , 223 , 220 , 217 , 214 
                        byte  213 , 210 , 212 , 212 , 207 , 203 , 199 , 195 
                        byte  191 , 184 , 181 , 174 , 167 , 153 , 138 , 124 
                        byte  102 , 69 , 31 , 10 , 6 , 4 , 6 , 4 
                        byte  2 , 3 , 3 , 3 , 3 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 4 , 5 
                        byte  5 , 5 , 8 , 9 , 11 , 23 , 67 , 140 
                        byte  187 , 203 , 210 , 215 , 221 , 230 , 235 , 237 
                        byte  241 , 245 , 247 , 249 , 251 , 251 , 250 , 247 
                        byte  245 , 244 , 236 , 226 , 226 , 224 , 221 , 220 
                        byte  213 , 211 , 204 , 200 , 198 , 202 , 204 , 201 
                        byte  206 , 213 , 219 , 224 , 224 , 220 , 217 , 214 
                        byte  213 , 211 , 214 , 212 , 207 , 203 , 201 , 196 
                        byte  190 , 185 , 181 , 173 , 166 , 154 , 141 , 125 
                        byte  100 , 66 , 32 , 12 , 6 , 5 , 6 , 3 
                        byte  2 , 4 , 3 , 3 , 3 , 2 , 2 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 4 , 5 
                        byte  5 , 6 , 7 , 9 , 14 , 24 , 69 , 143 
                        byte  190 , 200 , 208 , 214 , 219 , 225 , 231 , 236 
                        byte  241 , 246 , 248 , 250 , 252 , 251 , 250 , 247 
                        byte  246 , 247 , 240 , 230 , 227 , 221 , 216 , 217 
                        byte  212 , 205 , 198 , 194 , 192 , 196 , 199 , 197 
                        byte  202 , 211 , 217 , 222 , 221 , 217 , 215 , 214 
                        byte  213 , 213 , 214 , 211 , 206 , 203 , 202 , 196 
                        byte  188 , 187 , 181 , 171 , 165 , 156 , 144 , 124 
                        byte  95 , 57 , 30 , 13 , 7 , 5 , 5 , 3 
                        byte  3 , 4 , 3 , 3 , 3 , 2 , 2 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 4 , 5 
                        byte  5 , 6 , 6 , 9 , 16 , 26 , 71 , 144 
                        byte  189 , 196 , 205 , 214 , 219 , 222 , 229 , 237 
                        byte  240 , 245 , 247 , 250 , 251 , 252 , 250 , 249 
                        byte  248 , 249 , 244 , 234 , 230 , 221 , 214 , 215 
                        byte  211 , 202 , 195 , 191 , 188 , 192 , 196 , 194 
                        byte  199 , 207 , 215 , 221 , 220 , 216 , 215 , 215 
                        byte  215 , 215 , 213 , 209 , 205 , 204 , 201 , 195 
                        byte  187 , 185 , 179 , 168 , 162 , 153 , 142 , 119 
                        byte  86 , 50 , 28 , 14 , 7 , 5 , 4 , 2 
                        byte  5 , 3 , 3 , 3 , 3 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 4 , 5 
                        byte  5 , 6 , 6 , 9 , 15 , 26 , 73 , 143 
                        byte  182 , 193 , 203 , 214 , 220 , 223 , 230 , 236 
                        byte  238 , 239 , 242 , 247 , 250 , 251 , 251 , 250 
                        byte  249 , 247 , 243 , 236 , 233 , 224 , 215 , 214 
                        byte  209 , 202 , 194 , 188 , 183 , 188 , 192 , 189 
                        byte  192 , 203 , 213 , 220 , 220 , 217 , 216 , 216 
                        byte  216 , 214 , 212 , 208 , 206 , 203 , 199 , 193 
                        byte  188 , 181 , 176 , 166 , 158 , 149 , 137 , 113 
                        byte  78 , 47 , 28 , 15 , 7 , 5 , 5 , 2 
                        byte  5 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 4 , 5 
                        byte  5 , 7 , 6 , 9 , 13 , 25 , 74 , 141 
                        byte  174 , 190 , 200 , 213 , 220 , 223 , 229 , 235 
                        byte  234 , 233 , 238 , 244 , 249 , 251 , 251 , 250 
                        byte  249 , 243 , 240 , 235 , 233 , 226 , 216 , 214 
                        byte  207 , 203 , 194 , 185 , 180 , 184 , 187 , 183 
                        byte  184 , 199 , 209 , 218 , 219 , 216 , 215 , 215 
                        byte  215 , 214 , 211 , 209 , 207 , 203 , 197 , 192 
                        byte  190 , 179 , 175 , 166 , 158 , 148 , 135 , 111 
                        byte  75 , 48 , 29 , 15 , 6 , 5 , 5 , 2 
                        byte  5 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 4 , 4 
                        byte  5 , 8 , 4 , 13 , 10 , 27 , 66 , 140 
                        byte  171 , 183 , 194 , 209 , 219 , 225 , 229 , 232 
                        byte  235 , 239 , 235 , 236 , 243 , 250 , 251 , 250 
                        byte  251 , 243 , 234 , 232 , 228 , 216 , 212 , 210 
                        byte  202 , 202 , 197 , 186 , 178 , 178 , 179 , 177 
                        byte  176 , 194 , 209 , 214 , 218 , 218 , 212 , 215 
                        byte  212 , 211 , 209 , 207 , 206 , 204 , 199 , 193 
                        byte  188 , 182 , 173 , 164 , 154 , 144 , 133 , 110 
                        byte  83 , 59 , 33 , 16 , 6 , 3 , 6 , 5 
                        byte  2 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 2 , 2 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 4 , 4 
                        byte  5 , 7 , 4 , 12 , 11 , 25 , 61 , 138 
                        byte  171 , 180 , 189 , 202 , 213 , 220 , 225 , 229 
                        byte  232 , 235 , 235 , 237 , 242 , 246 , 248 , 248 
                        byte  248 , 239 , 231 , 227 , 223 , 216 , 213 , 210 
                        byte  204 , 202 , 194 , 183 , 172 , 167 , 169 , 173 
                        byte  174 , 184 , 205 , 216 , 220 , 216 , 210 , 213 
                        byte  212 , 212 , 208 , 204 , 202 , 200 , 197 , 192 
                        byte  188 , 181 , 173 , 165 , 156 , 145 , 135 , 114 
                        byte  88 , 61 , 33 , 16 , 7 , 4 , 6 , 4 
                        byte  2 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 4 , 4 
                        byte  5 , 6 , 5 , 10 , 13 , 22 , 53 , 133 
                        byte  171 , 179 , 185 , 195 , 206 , 214 , 221 , 226 
                        byte  229 , 229 , 233 , 237 , 239 , 241 , 244 , 246 
                        byte  246 , 240 , 233 , 224 , 218 , 216 , 213 , 208 
                        byte  203 , 200 , 192 , 182 , 170 , 158 , 160 , 169 
                        byte  171 , 176 , 199 , 212 , 215 , 212 , 209 , 211 
                        byte  210 , 212 , 209 , 205 , 203 , 201 , 198 , 193 
                        byte  188 , 179 , 172 , 165 , 155 , 144 , 134 , 116 
                        byte  93 , 65 , 34 , 15 , 8 , 6 , 6 , 3 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 4 , 4 
                        byte  5 , 6 , 6 , 8 , 13 , 18 , 44 , 125 
                        byte  170 , 179 , 183 , 190 , 199 , 206 , 213 , 221 
                        byte  226 , 223 , 229 , 232 , 231 , 233 , 239 , 242 
                        byte  241 , 239 , 233 , 222 , 214 , 214 , 211 , 205 
                        byte  201 , 197 , 187 , 180 , 169 , 153 , 153 , 162 
                        byte  163 , 171 , 189 , 200 , 204 , 208 , 209 , 208 
                        byte  206 , 208 , 207 , 205 , 203 , 201 , 197 , 190 
                        byte  184 , 176 , 169 , 162 , 152 , 140 , 130 , 114 
                        byte  94 , 70 , 35 , 14 , 8 , 6 , 5 , 3 
                        byte  4 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 4 , 4 
                        byte  4 , 5 , 7 , 7 , 12 , 17 , 38 , 113 
                        byte  170 , 178 , 181 , 186 , 192 , 197 , 203 , 211 
                        byte  218 , 218 , 224 , 226 , 222 , 224 , 231 , 234 
                        byte  232 , 232 , 228 , 217 , 209 , 208 , 206 , 201 
                        byte  198 , 193 , 183 , 175 , 163 , 146 , 144 , 151 
                        byte  152 , 162 , 175 , 191 , 199 , 205 , 206 , 202 
                        byte  202 , 203 , 204 , 202 , 199 , 196 , 192 , 185 
                        byte  180 , 173 , 166 , 159 , 149 , 136 , 127 , 112 
                        byte  94 , 70 , 34 , 13 , 7 , 5 , 4 , 2 
                        byte  5 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 4 
                        byte  4 , 4 , 7 , 6 , 10 , 17 , 33 , 96 
                        byte  164 , 176 , 179 , 183 , 189 , 191 , 194 , 201 
                        byte  208 , 213 , 219 , 220 , 216 , 216 , 221 , 224 
                        byte  223 , 226 , 222 , 215 , 205 , 197 , 193 , 190 
                        byte  187 , 189 , 178 , 167 , 152 , 136 , 133 , 140 
                        byte  144 , 149 , 162 , 185 , 200 , 205 , 199 , 190 
                        byte  194 , 199 , 200 , 198 , 193 , 188 , 185 , 181 
                        byte  177 , 166 , 160 , 155 , 147 , 135 , 124 , 109 
                        byte  92 , 64 , 30 , 11 , 6 , 4 , 4 , 3 
                        byte  5 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 4 
                        byte  4 , 5 , 7 , 6 , 8 , 15 , 26 , 73 
                        byte  149 , 172 , 174 , 179 , 186 , 189 , 188 , 191 
                        byte  195 , 201 , 209 , 212 , 209 , 206 , 209 , 213 
                        byte  213 , 217 , 214 , 211 , 199 , 182 , 176 , 176 
                        byte  171 , 177 , 169 , 156 , 141 , 127 , 123 , 130 
                        byte  138 , 138 , 145 , 171 , 193 , 198 , 184 , 167 
                        byte  173 , 185 , 188 , 187 , 180 , 174 , 170 , 167 
                        byte  164 , 152 , 148 , 147 , 142 , 131 , 119 , 103 
                        byte  84 , 53 , 24 , 9 , 5 , 4 , 5 , 3 
                        byte  4 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 1 , 1 , 1 , 1 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 4 
                        byte  4 , 5 , 7 , 7 , 5 , 13 , 20 , 55 
                        byte  136 , 167 , 169 , 174 , 183 , 186 , 184 , 183 
                        byte  183 , 187 , 197 , 203 , 201 , 197 , 199 , 203 
                        byte  205 , 204 , 203 , 203 , 191 , 170 , 164 , 166 
                        byte  161 , 162 , 159 , 147 , 132 , 121 , 116 , 122 
                        byte  134 , 131 , 131 , 154 , 180 , 187 , 169 , 145 
                        byte  149 , 165 , 170 , 172 , 166 , 158 , 153 , 149 
                        byte  146 , 140 , 137 , 138 , 136 , 126 , 114 , 96 
                        byte  76 , 45 , 19 , 7 , 5 , 4 , 6 , 3 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 3 , 3 , 3 , 3 , 3 , 4 
                        byte  4 , 2 , 6 , 8 , 3 , 12 , 16 , 40 
                        byte  107 , 166 , 167 , 167 , 172 , 176 , 186 , 175 
                        byte  169 , 173 , 184 , 191 , 193 , 192 , 187 , 186 
                        byte  194 , 192 , 192 , 189 , 184 , 167 , 151 , 151 
                        byte  150 , 145 , 149 , 144 , 130 , 117 , 111 , 113 
                        byte  120 , 137 , 130 , 135 , 159 , 171 , 149 , 126 
                        byte  122 , 138 , 153 , 162 , 157 , 147 , 141 , 142 
                        byte  147 , 138 , 133 , 131 , 132 , 118 , 103 , 89 
                        byte  66 , 32 , 17 , 6 , 5 , 4 , 4 , 4 
                        byte  3 , 3 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 3 , 3 , 3 , 3 , 4 
                        byte  4 , 3 , 4 , 6 , 3 , 10 , 12 , 28 
                        byte  81 , 154 , 171 , 161 , 159 , 161 , 169 , 172 
                        byte  167 , 160 , 174 , 184 , 185 , 183 , 176 , 175 
                        byte  184 , 184 , 179 , 173 , 173 , 161 , 144 , 139 
                        byte  136 , 135 , 140 , 138 , 129 , 117 , 108 , 107 
                        byte  113 , 131 , 130 , 136 , 152 , 160 , 141 , 114 
                        byte  103 , 119 , 135 , 148 , 149 , 142 , 134 , 135 
                        byte  142 , 137 , 135 , 132 , 128 , 112 , 94 , 77 
                        byte  52 , 26 , 13 , 5 , 5 , 4 , 3 , 4 
                        byte  3 , 3 , 3 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 3 , 3 , 3 , 3 , 4 
                        byte  4 , 5 , 3 , 7 , 6 , 10 , 10 , 19 
                        byte  52 , 125 , 171 , 163 , 159 , 154 , 155 , 166 
                        byte  161 , 154 , 165 , 172 , 175 , 176 , 170 , 168 
                        byte  174 , 179 , 171 , 161 , 162 , 156 , 141 , 133 
                        byte  128 , 128 , 133 , 135 , 132 , 123 , 111 , 106 
                        byte  109 , 116 , 122 , 129 , 137 , 144 , 135 , 113 
                        byte  97 , 99 , 110 , 123 , 130 , 130 , 124 , 124 
                        byte  130 , 127 , 130 , 130 , 124 , 106 , 87 , 68 
                        byte  42 , 19 , 9 , 4 , 5 , 4 , 3 , 4 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  4 , 5 , 2 , 7 , 7 , 8 , 10 , 15 
                        byte  32 , 86 , 157 , 168 , 163 , 153 , 148 , 155 
                        byte  154 , 157 , 161 , 162 , 166 , 173 , 171 , 167 
                        byte  169 , 174 , 168 , 157 , 153 , 148 , 137 , 133 
                        byte  130 , 129 , 132 , 135 , 138 , 134 , 121 , 112 
                        byte  112 , 114 , 119 , 120 , 118 , 118 , 113 , 99 
                        byte  86 , 77 , 77 , 80 , 91 , 99 , 97 , 96 
                        byte  100 , 110 , 120 , 124 , 118 , 100 , 80 , 58 
                        byte  32 , 13 , 6 , 5 , 6 , 4 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 1 , 5 , 6 , 4 , 8 , 13 
                        byte  20 , 52 , 124 , 160 , 160 , 148 , 144 , 142 
                        byte  148 , 157 , 159 , 158 , 162 , 169 , 168 , 163 
                        byte  165 , 164 , 166 , 155 , 146 , 139 , 131 , 132 
                        byte  134 , 135 , 134 , 135 , 140 , 141 , 132 , 120 
                        byte  117 , 115 , 111 , 105 , 98 , 90 , 83 , 77 
                        byte  72 , 63 , 54 , 49 , 55 , 64 , 65 , 68 
                        byte  77 , 97 , 112 , 118 , 111 , 92 , 69 , 46 
                        byte  20 , 9 , 5 , 5 , 6 , 4 , 2 , 3 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  3 , 4 , 2 , 4 , 5 , 2 , 5 , 11 
                        byte  14 , 27 , 83 , 135 , 151 , 146 , 144 , 132 
                        byte  139 , 147 , 153 , 156 , 159 , 163 , 160 , 157 
                        byte  161 , 159 , 165 , 157 , 147 , 140 , 131 , 131 
                        byte  136 , 139 , 135 , 132 , 135 , 139 , 134 , 125 
                        byte  121 , 112 , 98 , 88 , 83 , 74 , 66 , 64 
                        byte  65 , 57 , 49 , 42 , 41 , 44 , 46 , 56 
                        byte  71 , 89 , 107 , 112 , 103 , 83 , 58 , 36 
                        byte  15 , 8 , 5 , 5 , 6 , 3 , 2 , 3 
                        byte  3 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  3 , 4 , 4 , 4 , 5 , 3 , 5 , 10 
                        byte  10 , 16 , 44 , 94 , 130 , 136 , 138 , 127 
                        byte  128 , 132 , 140 , 144 , 148 , 154 , 153 , 152 
                        byte  158 , 158 , 162 , 156 , 154 , 151 , 135 , 129 
                        byte  133 , 134 , 129 , 121 , 119 , 124 , 124 , 120 
                        byte  117 , 112 , 89 , 74 , 70 , 63 , 55 , 53 
                        byte  54 , 51 , 46 , 39 , 37 , 37 , 39 , 51 
                        byte  67 , 87 , 102 , 104 , 92 , 70 , 45 , 27 
                        byte  12 , 7 , 4 , 4 , 5 , 3 , 2 , 4 
                        byte  3 , 3 , 3 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  3 , 2 , 3 , 2 , 4 , 4 , 5 , 8 
                        byte  8 , 14 , 19 , 55 , 103 , 117 , 124 , 122 
                        byte  121 , 121 , 126 , 128 , 134 , 145 , 148 , 149 
                        byte  155 , 156 , 157 , 152 , 158 , 159 , 137 , 124 
                        byte  126 , 124 , 119 , 109 , 103 , 107 , 110 , 110 
                        byte  110 , 103 , 75 , 58 , 56 , 52 , 48 , 49 
                        byte  49 , 50 , 45 , 39 , 39 , 41 , 44 , 53 
                        byte  66 , 88 , 101 , 97 , 81 , 58 , 32 , 16 
                        byte  6 , 7 , 4 , 4 , 4 , 2 , 3 , 4 
                        byte  3 , 3 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 4 , 5 
                        byte  6 , 11 , 11 , 28 , 62 , 94 , 107 , 105 
                        byte  102 , 111 , 113 , 116 , 122 , 129 , 134 , 142 
                        byte  153 , 153 , 148 , 146 , 152 , 151 , 134 , 116 
                        byte  110 , 106 , 102 , 99 , 89 , 89 , 95 , 94 
                        byte  93 , 82 , 65 , 50 , 44 , 44 , 43 , 42 
                        byte  43 , 45 , 45 , 40 , 39 , 44 , 49 , 61 
                        byte  77 , 91 , 93 , 86 , 65 , 39 , 21 , 11 
                        byte  6 , 4 , 4 , 4 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 4 , 5 
                        byte  5 , 7 , 7 , 16 , 38 , 66 , 87 , 93 
                        byte  92 , 95 , 99 , 102 , 107 , 112 , 117 , 126 
                        byte  138 , 146 , 142 , 138 , 139 , 137 , 123 , 106 
                        byte  98 , 92 , 90 , 87 , 77 , 73 , 77 , 73 
                        byte  72 , 67 , 55 , 44 , 41 , 41 , 40 , 41 
                        byte  43 , 43 , 42 , 40 , 41 , 48 , 56 , 69 
                        byte  82 , 91 , 84 , 67 , 45 , 25 , 12 , 7 
                        byte  5 , 4 , 4 , 4 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 4 , 5 
                        byte  5 , 5 , 6 , 8 , 17 , 37 , 62 , 76 
                        byte  78 , 81 , 87 , 92 , 96 , 97 , 97 , 103 
                        byte  113 , 125 , 125 , 121 , 118 , 117 , 109 , 96 
                        byte  87 , 80 , 80 , 79 , 69 , 62 , 61 , 56 
                        byte  55 , 51 , 45 , 39 , 39 , 38 , 37 , 39 
                        byte  43 , 44 , 41 , 41 , 45 , 53 , 67 , 81 
                        byte  88 , 88 , 70 , 46 , 26 , 13 , 7 , 5 
                        byte  6 , 4 , 4 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 4 , 4 
                        byte  4 , 4 , 7 , 8 , 9 , 20 , 40 , 56 
                        byte  62 , 65 , 74 , 83 , 88 , 87 , 83 , 81 
                        byte  86 , 100 , 105 , 104 , 97 , 96 , 93 , 85 
                        byte  77 , 72 , 73 , 74 , 64 , 56 , 54 , 49 
                        byte  49 , 44 , 41 , 39 , 39 , 38 , 37 , 38 
                        byte  41 , 46 , 42 , 43 , 49 , 59 , 75 , 87 
                        byte  86 , 75 , 54 , 30 , 16 , 10 , 6 , 5 
                        byte  6 , 4 , 4 , 3 , 3 , 2 , 2 , 2 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 3 , 4 
                        byte  4 , 3 , 6 , 7 , 7 , 10 , 20 , 33 
                        byte  44 , 48 , 57 , 67 , 74 , 76 , 72 , 67 
                        byte  67 , 80 , 89 , 90 , 81 , 77 , 75 , 70 
                        byte  64 , 62 , 62 , 64 , 55 , 48 , 47 , 43 
                        byte  44 , 42 , 39 , 38 , 40 , 39 , 38 , 37 
                        byte  38 , 47 , 46 , 50 , 57 , 67 , 81 , 83 
                        byte  73 , 53 , 35 , 17 , 9 , 7 , 5 , 3 
                        byte  4 , 4 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 4 , 5 , 6 , 5 , 7 , 17 
                        byte  27 , 37 , 44 , 52 , 59 , 64 , 62 , 57 
                        byte  57 , 63 , 72 , 74 , 67 , 63 , 61 , 58 
                        byte  56 , 55 , 54 , 55 , 47 , 43 , 43 , 40 
                        byte  41 , 38 , 37 , 37 , 38 , 39 , 38 , 38 
                        byte  38 , 48 , 56 , 64 , 68 , 73 , 78 , 71 
                        byte  55 , 33 , 21 , 9 , 5 , 5 , 3 , 3 
                        byte  4 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 4 , 3 , 4 , 5 , 5 , 5 , 9 
                        byte  14 , 25 , 32 , 39 , 45 , 52 , 53 , 51 
                        byte  51 , 50 , 57 , 58 , 55 , 53 , 52 , 51 
                        byte  52 , 50 , 48 , 48 , 43 , 41 , 42 , 39 
                        byte  39 , 37 , 36 , 37 , 38 , 39 , 39 , 40 
                        byte  42 , 51 , 66 , 74 , 70 , 67 , 63 , 48 
                        byte  33 , 18 , 12 , 6 , 4 , 5 , 4 , 4 
                        byte  4 , 3 , 3 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 4 , 6 , 7 , 6 
                        byte  4 , 8 , 17 , 26 , 34 , 43 , 46 , 46 
                        byte  48 , 46 , 49 , 49 , 47 , 48 , 46 , 45 
                        byte  48 , 45 , 42 , 42 , 39 , 40 , 42 , 38 
                        byte  38 , 37 , 38 , 39 , 40 , 39 , 40 , 42 
                        byte  45 , 52 , 72 , 76 , 63 , 54 , 44 , 28 
                        byte  15 , 9 , 6 , 4 , 4 , 5 , 5 , 3 
                        byte  1 , 3 , 3 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 4 , 4 , 5 , 5 
                        byte  5 , 7 , 7 , 12 , 21 , 30 , 36 , 40 
                        byte  42 , 42 , 43 , 44 , 44 , 43 , 43 , 44 
                        byte  45 , 45 , 42 , 39 , 38 , 39 , 40 , 39 
                        byte  38 , 38 , 39 , 39 , 39 , 41 , 43 , 45 
                        byte  45 , 54 , 62 , 63 , 50 , 33 , 23 , 15 
                        byte  8 , 5 , 4 , 4 , 4 , 3 , 3 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 4 , 4 , 4 , 5 
                        byte  5 , 6 , 6 , 8 , 13 , 18 , 24 , 31 
                        byte  36 , 39 , 41 , 43 , 44 , 44 , 43 , 43 
                        byte  44 , 44 , 42 , 41 , 41 , 42 , 42 , 41 
                        byte  40 , 39 , 41 , 42 , 42 , 43 , 45 , 45 
                        byte  44 , 43 , 45 , 41 , 30 , 19 , 13 , 9 
                        byte  5 , 4 , 4 , 4 , 4 , 3 , 3 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 3 , 3 , 3 , 4 , 4 , 4 
                        byte  4 , 3 , 4 , 5 , 6 , 7 , 11 , 18 
                        byte  25 , 31 , 34 , 38 , 41 , 43 , 43 , 43 
                        byte  44 , 41 , 41 , 42 , 42 , 43 , 43 , 43 
                        byte  43 , 45 , 47 , 47 , 45 , 43 , 42 , 39 
                        byte  36 , 29 , 25 , 19 , 12 , 8 , 7 , 5 
                        byte  4 , 4 , 4 , 4 , 3 , 3 , 3 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 4 
                        byte  4 , 2 , 3 , 5 , 5 , 5 , 5 , 9 
                        byte  13 , 19 , 23 , 28 , 33 , 36 , 39 , 41 
                        byte  42 , 42 , 43 , 44 , 44 , 44 , 45 , 47 
                        byte  48 , 50 , 50 , 47 , 42 , 36 , 31 , 26 
                        byte  22 , 16 , 12 , 8 , 6 , 6 , 5 , 4 
                        byte  3 , 4 , 4 , 3 , 3 , 3 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 4 , 5 , 5 , 4 , 5 
                        byte  7 , 9 , 12 , 16 , 20 , 25 , 28 , 32 
                        byte  33 , 39 , 41 , 44 , 45 , 45 , 45 , 46 
                        byte  47 , 44 , 42 , 38 , 31 , 24 , 18 , 13 
                        byte  9 , 8 , 6 , 4 , 5 , 5 , 4 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 5 , 3 , 3 , 3 , 4 , 4 , 4 
                        byte  6 , 4 , 5 , 7 , 10 , 12 , 16 , 18 
                        byte  20 , 24 , 28 , 32 , 35 , 35 , 33 , 32 
                        byte  31 , 27 , 26 , 22 , 17 , 12 , 9 , 6 
                        byte  4 , 6 , 5 , 4 , 4 , 3 , 2 , 3 
                        byte  4 , 3 , 3 , 3 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 4 , 3 , 2 , 3 , 3 , 3 , 4 
                        byte  5 , 4 , 4 , 4 , 5 , 6 , 7 , 8 
                        byte  9 , 10 , 12 , 15 , 17 , 17 , 16 , 14 
                        byte  13 , 12 , 12 , 10 , 7 , 6 , 6 , 5 
                        byte  3 , 5 , 5 , 5 , 3 , 2 , 3 , 4 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 3 , 4 , 4 , 2 , 3 
                        byte  4 , 5 , 4 , 4 , 4 , 5 , 5 , 5 
                        byte  5 , 6 , 6 , 6 , 6 , 6 , 7 , 7 
                        byte  7 , 5 , 6 , 6 , 5 , 4 , 5 , 5 
                        byte  4 , 2 , 3 , 4 , 2 , 2 , 3 , 3 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 4 , 4 , 4 , 4 , 4 , 4 , 4 
                        byte  4 , 4 , 4 , 4 , 4 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 4 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 3 , 3 , 3 , 3 , 3 , 3 , 3 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  3 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 2 , 2 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 2 , 2 , 1 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 1 , 1 , 1 , 1 , 2 
                        byte  2 , 1 , 1 , 2 , 2 , 2 , 2 , 1 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 1 , 1 , 1 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 
                        byte  2 , 2 , 1 , 1 , 1 , 1 , 1 , 1 
                        byte  2 , 2 , 2 , 1 , 1 , 1 , 1 , 2 
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        byte 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 


                        
displayIndicator        byte    1                                          ' Video output control.
syncIndicator           byte    0                                          ' Video update control.
cogNumber               byte    0                                          ' Cog ID.
                        
' /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

{{

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//                                                  TERMS OF USE: MIT License
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
// Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
// WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
// COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
}}